@@ -8,13 +8,12 @@ __docformat__ = "restructuredtext en"
 
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import ITreeAdapter
-from cubicweb.selectors import is_instance
-
+from cubicweb.predicates import is_instance
 
 class Folder(AnyEntity):
     """customized class for Folder entities"""
     __regid__ = 'Folder'
-    fetch_attrs, fetch_order = fetch_config(['name'])
+    fetch_attrs, cw_fetch_order = fetch_config(['name'])
 
 
 class FolderITreeAdapter(ITreeAdapter):
