@@ -10,8 +10,8 @@ _ = unicode
 
 from cubicweb.utils import UStringIO
 from cubicweb.view import EntityView, EntityStartupView
-from cubicweb.selectors import (none_rset, is_instance, relation_possible,
-                                score_entity)
+from cubicweb.predicates import (none_rset, is_instance, relation_possible,
+                                 score_entity)
 from cubicweb.web import uicfg, component
 from cubicweb.web.httpcache import GMTOFFSET
 from cubicweb.web.views import primary, baseviews
@@ -96,13 +96,16 @@ class FolderPrimaryView(primary.PrimaryView):
                    'null')
         childrenrset = itree.different_type_children(entities=False)
         if childrenrset:
-            vid = len(childrenrset.column_types(0)) == 1 and 'sameetypelist' or 'list'
-            view = self._cw.vreg['views'].select(vid, self._cw, rset=childrenrset)
-            nav_html = UStringIO()
-            view.paginate(w=nav_html.write)
-            self.w(_(nav_html.getvalue()))
-            view.render(w=self.w)
-            self.w(_(nav_html.getvalue()))
+            self.render_children(childrenrset)
+
+    def render_children(self, rset):
+        vid = len(rset.column_types(0)) == 1 and 'sameetypelist' or 'list'
+        view = self._cw.vreg['views'].select(vid, self._cw, rset=rset)
+        nav_html = UStringIO()
+        view.paginate(w=nav_html.write)
+        self.w(_(nav_html.getvalue()))
+        view.render(w=self.w)
+        self.w(_(nav_html.getvalue()))
 
 
 class FolderChildrenView(EntityView):
